@@ -29,8 +29,8 @@ use Exporter 5.57 'import';     # exported import method
 #=====================================================================
 # Package Global Variables:
 
-our $VERSION = '1.001';
-# This file is part of HTML-Embellish 1.001 (April 11, 2015)
+our $VERSION = '1.002';
+# This file is part of HTML-Embellish 1.002 (January 9, 2016)
 
 our @EXPORT = qw(embellish);
 
@@ -135,6 +135,7 @@ sub processTextRefs
     s/'(?=
         (?: angmans?
           | aves?
+          | ay
           | cause
           | cept
           | d
@@ -160,6 +161,7 @@ sub processTextRefs
           | tw(?:asn?|ere?n?|ould\w*)
           | ud
           | uns?
+          | y
         ) \b
         | \d\d\W?s
         | \d\d(?!\w)
@@ -310,8 +312,8 @@ HTML::Embellish - Typographically enhance HTML trees
 
 =head1 VERSION
 
-This document describes version 1.001 of
-HTML::Embellish, released April 11, 2015.
+This document describes version 1.002 of
+HTML::Embellish, released January 9, 2016.
 
 =head1 SYNOPSIS
 
@@ -462,7 +464,7 @@ L<< https://github.com/madsen/html-embellish >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Christopher J. Madsen.
+This software is copyright (c) 2016 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
